==> haskell-hslua-list-1.1.4-22.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-list
version:              1.1.4
visibility:           public
id:                   hslua-list-1.1.4-8z81DILtRHw6GXhp4f5B7Y
key:                  hslua-list-1.1.4-8z81DILtRHw6GXhp4f5B7Y
license:              MIT
copyright:            © 2022-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Opinionated, but extensible Lua list type.
description:          List type for Lua, with a Haskell interface.
category:             Foreign
abi:                  71ed62c47e10030c78e82515e2c34e11
exposed:              True
exposed-modules:      HsLua.List
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-list-1.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-list-1.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-list-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-list
hs-libraries:         HShslua-list-1.1.4-8z81DILtRHw6GXhp4f5B7Y
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    hslua-core-2.3.2-LsuRv5joEv2BEnjW1fCbrM

haddock-interfaces:   /usr/share/doc/haskell-hslua-list/html/hslua-list.haddock
haddock-html:         /usr/share/doc/haskell-hslua-list/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-list-1.1.4-23-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-list.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-list
version:              1.1.4
visibility:           public
id:                   hslua-list-1.1.4-5xI0BhgiDrz56UbXARVZLL
key:                  hslua-list-1.1.4-5xI0BhgiDrz56UbXARVZLL
license:              MIT
copyright:            © 2022-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Opinionated, but extensible Lua list type.
description:          List type for Lua, with a Haskell interface.
category:             Foreign
abi:                  cbc9b5b82873bffa5d2e47efe7c5c3fc
exposed:              True
exposed-modules:      HsLua.List
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-list-1.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-list-1.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-list-1.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-list
hs-libraries:         HShslua-list-1.1.4-5xI0BhgiDrz56UbXARVZLL
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    hslua-core-2.3.2-6IHXwFbRgmjH5Bn36TUerg

haddock-interfaces:   /usr/share/doc/haskell-hslua-list/html/hslua-list.haddock
haddock-html:         /usr/share/doc/haskell-hslua-list/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
